import axios from 'axios';
import { Message } from 'element-ui';
import store from '@/store';
import { getSessionID } from '@/utils/auth';

axios.defaults.withCredentials = true; // 跨域请求时是否需要使用凭证
axios.defaults.dataType = 'json';
axios.defaults.headers['cache-control'] = 'no-cache';
axios.defaults.headers['Content-Type'] = 'application/json';
axios.defaults.headers['X-Requested-With'] = 'XMLHttpRequest';

const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API + '/GCLSLearnWebSI/ServiceInterface',
  // withCredentials: true, // 跨域请求时发送 cookies
  timeout: 5000
});

// 请求拦截器
service.interceptors.request.use({});

//响应拦截器
service.interceptors.response.use(
  response => {
    const res = response.data;

    if (res.code === 404) {
      Message({
        message: '请求的资源不存在',
        type: 'error',
        duration: 3 * 1000
      });
      return Promise.reject(new Error(res.message || 'Error'));
    }

    // 返回数据失败
    if (res.status === 0) {
      Message({
        message: res.error,
        type: 'error',
        duration: 3 * 1000
      });
      return Promise.reject(new Error(res.error || 'Error'));
    }
    return res;
  },
  error => {
    Message({
      message: error.message,
      type: 'error',
      duration: 3 * 1000
    });
    return Promise.reject(error);
  }
);

/**
 * 得到必需的请求参数
 * @param {String} MethodName 请求方法名
 * @returns {Object} 返回必需的请求参数
 * */
export function getRequestParameter(MethodName) {
  return {
    MethodName,
    UserCode: store.state.user.user_code,
    UserType: store.state.user.user_type,
    SessionID: getSessionID()
  };
}

export { service as request };
